#
# spec file for package perl-Test-Simple
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Test-Simple
Version:        1.001002
Release:        4.2
%define cpan_name Test-Simple
Summary:        Basic utilities for writing tests.
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Test-Simple/
Source:         http://www.cpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
#BuildRequires: perl(Dev::Null)
#BuildRequires: perl(MyOverload)
#BuildRequires: perl(Test::Builder::IO::Scalar)
#BuildRequires: perl(Test::Builder::NoOutput)
#BuildRequires: perl(Test::Simple::Catch)
#BuildRequires: perl(TieOut)
%{perl_requires}

%description
** If you are unfamiliar with testing *read Test::Tutorial* first! **

This is an extremely simple, extremely basic module for writing tests
suitable for CPAN modules and other pursuits. If you wish to do more
complicated testing, use the Test::More module (a drop-in replacement for
this one).

The basic unit of Perl testing is the ok. For each thing you want to test
your program will print out an "ok" or "not ok" to indicate pass or fail.
You do this with the ok() function (see below).

The only other constraint is you must pre-declare how many tests you plan
to run. This is in case something goes horribly wrong during the test and
your test program aborts, or skips a test or whatever. You do this like so:

    use Test::Simple tests => 23;

You must have a plan.

* *ok*

    ok( $foo eq $bar, $name );
    ok( $foo eq $bar );

  ok() is given an expression (in this case '$foo eq $bar'). If it's true,
  the test passed. If it's false, it didn't. That's about it.

  ok() prints out either "ok" or "not ok" along with a test number (it
  keeps track of that for you).

    # This produces "ok 1 - Hell not yet frozen over" (or not ok)
    ok( get_temperature($hell) > 0, 'Hell not yet frozen over' );

  If you provide a $name, that will be printed along with the "ok/not ok"
  to make it easier to find your test when if fails (just search for the
  name). It also makes it easier for the next guy to understand what your
  test is for. It's highly recommended you use test names.

  All tests are run in scalar context. So this:

      ok( @stuff, 'I have some stuff' );

  will do what you mean (fail if stuff is empty)

Test::Simple will start by printing number of tests run in the form "1..M"
(so "1..5" means you're going to run 5 tests). This strange format lets
Test::Harness know how many tests you plan on running in case something
goes horribly wrong.

If all your tests passed, Test::Simple will exit with zero (which is
normal). If anything failed it will exit with how many failed. If you run
less (or more) tests than you planned, the missing (or extras) will be
considered failures. If no tests were ever run Test::Simple will throw a
warning and exit with 255. If the test died, even after having successfully
completed all its tests, it will still be considered a failure and will
exit with 255.

So the exit codes are...

    0                   all tests successful
    255                 test died or all passed but wrong # of tests run
    any other number    how many failed (including missing or extras)

If you fail more than 254 tests, it will be reported as 254.

This module is by no means trying to be a complete testing system. It's
just to get you started. Once you're off the ground its recommended you
look at the Test::More manpage.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes examples README TODO

%changelog
* Tue Dec 10 2013 coolo@suse.com
- updated to 1.001002
  * restore ability to use regex with test_err and test_out
    (Zefram) [rt.cpan.org #89655] [github #389] [github #387]
    Bug Fixes
  * Fix precedence error with (return ... and ...)
    (nthykier) [github #385]
    Doc Changes
  * Add a shorter work around for the UTF-8 output problem.
    (Michael G Schwern)
    Bug Fixes
  * Test::Builder::Tester now works with subtests.
    (Michael G Schwern) [github 350]
  * Fix test_fail() inside a do statement.
    (nnutter) [github #369]
    New Features
  * A subtest will put its name at the front of its results to make
    subtests easier to read. [github #290] [github #364]
    (Brendan Byrd)
    Feature Changes
  * like() and unlike() no longer warn about undef. [github #335]
    (Michael G Schwern)
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Feb 23 2011 lars@linux-schulserver.de
- update to 0.98:
  + subtest() should not fail if $? is non-zero.
  + The behavior of is() and undef has been documented.
  + Adapted the tests for the new Perl 5.14 regex stringification.
  + The filehandles used by default will now inherit any filehandle
    disciplines from STDOUT and STDERR IF AND ONLY IF they were applied
    before Test::Builder is loaded.
- also package the examples in docdir
* Tue Nov 30 2010 coolo@novell.com
- buildrequire perl-devel on fedora
* Thu Sep  9 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- noarch pkg
- bzipped Source
- added bcond_with pod
- fixed deps
  o Removed: Prov perl-Test-More, perl-Test-Builder
  o fixed dep for *Pod*
* Fri Aug 27 2010 pascal.bleser@opensuse.org
- update to 0.96
  * You can call done_testing() again after reset() [googlecode 59]
* Mon Jul  5 2010 jw@novell.com
- looong time no updated. 0.88 is needed for CPANPLUS packages.
  Let's fast forward this one.
- Update to 0.95_02
  See http://cpansearch.perl.org/src/MSCHWERN/Test-Simple-0.95_02/Changes
* Tue Feb 12 2008 lars@linux-schulserver.de
- Update to 0.74
  + Add abstract and author to the meta information.
  + Put the use_ok() fix from 0.71 back.
  + Fixed an obscure problem with is_deeply() and overloading ==
    [rt.cpan.org 20768].  Thanks Sisyphus.
  + Removed dependency on Text::Soundex [rt.cpan.org 25022]
  + Fixed a 5.5.x failure in fail-more.t
  + Got rid of the annoying sort_bug.t test that revealed problems with some
    threaded perls.  It was testing the deprecated eq_* functions and not
    worth the bother.  Now it tests is_deeply().  [rt.cpan.org 17791]
  + Minor POD mistake in Test::Builder [rt.cpan.org 28869]
  + Test::FAQ has been updated with some more answers.
  + Fixed the "LICENSE is not a known MakeMaker parameter name" warning
    on older MakeMakers for real this time.
* Tue Jul 24 2007 lars@linux-schulserver.de
- initial version 0.70
